==> omnisaude_chatbot-0.0.5%2B2.tar.gz: lib/app/chatbot/switch_content/switch_content_controller.dart <==
import 'package:flutter_modular/flutter_modular.dart';
import 'package:omnisaude_chatbot/app/connection/connection.dart';
import 'package:omnisaude_chatbot/app/core/models/message_content_model.dart';
import 'package:omnisaude_chatbot/app/core/models/option_model.dart';
import 'package:omnisaude_chatbot/app/core/models/ws_message_model.dart';
import 'package:rx_notifier/rx_notifier.dart';

class SwitchContentController extends Disposable {
  final RxList<Option> selectedOptions = RxList();
  RxList<Option> filteredOptions = RxList();

  Future<void> onSendOptionsMessage(Connection connection) async {
    try {
      final List<String> _options = List<String>.empty(growable: true);
      selectedOptions.forEach((option) => _options.add(option.id));
      final MessageContent _messageContent = MessageContent(
        extras: {"options": _options},
      );
      final WsMessage _message = WsMessage(messageContent: _messageContent);
      await connection.onSendMessage(_message);
      selectedOptions.clear();
    } catch (e) {
      print("erro ao enviar uma option message: $e");
    }
  }

  void onSearchIntoOptions(List<Option> options, String filter) {
    filteredOptions.clear();
    options.forEach(
          (Option option) {
        if (option.title.toLowerCase().contains(filter.toLowerCase()) ||
            option.id.toLowerCase().contains(filter)) {
          filteredOptions.add(option);
        }
      },
    );
  }

  @override
  void dispose() {
    selectedOptions.dispose();
    filteredOptions.dispose();
  }
}

==> omnisaude_chatbot-0.0.8%2B2.tar.gz: lib/app/chatbot/switch_content/switch_content_controller.dart <==
import 'package:flutter_modular/flutter_modular.dart';
import 'package:rx_notifier/rx_notifier.dart';

import 'package:omnisaude_chatbot/app/connection/chat_connection.dart';
import 'package:omnisaude_chatbot/app/core/models/message_content_model.dart';
import 'package:omnisaude_chatbot/app/core/models/option_model.dart';
import 'package:omnisaude_chatbot/app/core/models/ws_message_model.dart';

class SwitchContentController extends Disposable {
  RxList<Option> selectedOptions = RxList();
  RxList<Option> filteredOptions = RxList();

  Future<void> onSendOptionsMessage(ChatConnection connection) async {
    try {
      final List<String> _options = List<String>.empty(growable: true);
      selectedOptions.forEach((option) => _options.add(option.id));
      final MessageContent _messageContent = MessageContent(
        extras: {"options": _options},
      );
      final WsMessage _message = WsMessage(messageContent: _messageContent);
      await connection.onSendMessage(_message);
      selectedOptions.clear();
    } catch (e) {
      print("erro ao enviar uma option message: $e");
    }
  }

  void onSearchIntoOptions(List<Option> options, String filter) {
    filteredOptions.clear();
    options.forEach(
      (Option option) {
        if (option.title.toLowerCase().contains(filter.toLowerCase()) ||
            option.id.toLowerCase().contains(filter)) {
          filteredOptions.add(option);
        }
      },
    );
  }

  @override
  void dispose() {
    selectedOptions.dispose();
    filteredOptions.dispose();
  }
}
